#
# spec file for package python-python-redmine
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-redmine
Version:        2.5.0
Release:        1.2
Summary:        Python library for the Redmine RESTful API
License:        Apache-2.0
URL:            https://python-redmine.com
Source:         https://files.pythonhosted.org/packages/source/p/python-redmine/python-redmine-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.31.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.31.0
BuildArch:      noarch
%python_subpackages

%description
Python Redmine is a library for communicating with a Redmine
project management application. Redmine exposes some of it's data
via REST API for which Python Redmine provides a simple but
powerful Pythonic API inspired by a well-known Django ORM.

%prep
%autosetup -p1 -n python-redmine-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k "not (test_engine_init or test_session_key or test_session_requests)"

%files %{python_files}
%license LICENSE
%doc CHANGELOG.rst README.rst
%{python_sitelib}/redminelib
%{python_sitelib}/python_redmine-%{version}.dist-info

%changelog
* Sun Apr  7 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.0
  Deprecations:
  * Requests version required >= 2.31.0
  New Features:
  * Pro Edition: RedmineUP Products plugin support
  * Issue copying (see docs for details)
  Improvements:
  * dir(resource) and list(resource) now also show properties of
    an object.
  * Support for issues_assigned and issues_authored relations in
    User object
  * Original filename will be used as a filename for all uploaded
    files if a path was provided and filename wasn't set.
  * Pro Edition: Added support for RedmineUP Contact avatar
    add/update operations (see docs for details).
  * Pro Edition: Added support for RedmineUP DealCategory create(),
    update(), delete() operations (see docs for details).
  * Pro Edition: RedmineUP CrmQuery resource now supports
    invoices and expenses relation attributes.
  * PerformanceWarning will be issued when Python-Redmine does some
    unnecessary redirects before the actual request is made.
  Changes:
  * Backwards Incompatible: API key is now being sent in the
    X-Redmine-API-Key header instead of the key GET parameter which
    makes things more secure in case of a failed connection, but
    it might created issues for servers that don't do custom
    request header forwarding by default, so be sure to check your
    web server before upgrading (Issue #328 and Issue #330).
  * Backwards Incompatible: User all operation now really returns
    all users, i.e. not only active, but locked, registered and
    anonymous as well instead of only returning just active users
    in previous versions due to the respect to Redmine's standard
    behaviour.
  Bugfixes:
  * Tests were failing on Python 3.12 (Issue #332).
  * Some closed Issues weren't converted to Resource objects
    using redmine.search().
  * Pro Edition: RedmineUP Invoice resource order attribute was
    returned as a dict instead of being converted to Resource
    object.
  * Pro Edition: RedmineUP CrmQuery resource deals and contacts
    relation attributes didn't work.
  * Pro Edition: RedmineUP DealStatus resource deals relation
    attribute didn't work.
  Documentation:
  * Mentioned support for author_id in Issue's resource filter
    operation.
- Drop not longer needed patches
  * 328.patch
  * support-python-312.patch
* Mon Mar  4 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject and autosetup macros.
- Add patch support-python-312.patch, support Python 3.12.
* Tue Sep 26 2023 Martin Hauke <mardnh@gmx.de>
- Add 328.patch to workaround "API key leakage on exception"
  described in boo#1215722
  https://github.com/maxtepkeev/python-redmine/issues/330
  https://github.com/maxtepkeev/python-redmine/pull/328
* Sat Jan 21 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.0
  New Features:
  * Timezone support.
  Improvements:
  * Added support for Python 3.10, 3.11 and latest PyPy
  * Added support for `allowed_statuses` to ``include`` param and
    on demand includes for Issue resource.
  * Added support for `issue_custom_fields` to ``include``
    param and on demand includes for Project resource.
  - Added support for `comments` and `attachments` to ``include``
    param and on demand includes for News resource.
  * Added support for Project ``close()``, ``reopen()``,
    ``archive()``, ``unarchive()`` operations.
  * Added support for updating and deleting issue journals.
  Backwards Incompatible Changes:
  * Switched to pytest instead of nose as nose project is dead
  * Removed usage of distutils.LooseVersion internally since it
    became deprecated and caused warnings, because of that all
    version info internally is now being represented as tuples
    and not strings as before.
  Bugfixes:
  * Stop raising `ResourceAttrError` for attributes that actually
    exist, but their value is `None`.
  * Project resource ``default_assignee`` attribute was returned
    as a dict instead of being converted to Resource object.
  * Project resource ``time_entry_activities`` attribute was
    returned as a list instead of being converted to ResourceSet
    object.
* Tue Apr 12 2022 Markéta Machová <mmachova@suse.com>
- do not take python2 into account, it is long dead... and drop mock requirement
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Replace nose with pytest
* Wed Aug  5 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 2.3.0
  * Support custom filename in ``redmine.upload()``
  * Support for ``get()`` and ``update()`` operations for ``/my/account`` endpoint which doesn't require admin
    privileges by using ``me`` as an id, i.e. ``redmine.user.get('me')`` or ``redmine.user.update('me',firstname='John')``
    (requires Redmine >= 4.1.0)
  * News ``create()``, ``update()``, ``delete()`` operations support (requires Redmine >= 4.1.0)
  * ResourceSet's ``export()`` method now supports ``columns`` keyword argument which can be either an iterable
    of column names, an "all" string which tells Python*Redmine to export all available columns, "all_gui" string
    for GUI like behaviour or iterable of elements with "all_gui" string and additional columns to export
  * Added support for special characters in WikiPage titles (`Issue #222 <https://github.com/maxtepkeev/python-redmine/
    issues/222>`__) (thanks to `Radek Czajka <https://github.com/rczajka>`__)
  * Added ``return_response`` and ``ignore_response`` parameters to engine which allow to skip response processing
    and speed up the create/update/delete operation in case response body isn't needed (see
    `docs <https://python*redmine.com/advanced/request_engines.html#session>`__ for details)
  * *Backwards Incompatible:* Requests version required >= 2.23.0
  * *Backwards Incompatible:* Removed Python 3.4 support as it's not supported by Requests anymore
- Drop apparently obsolete python-python-redmine-use-system-requests.patch
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the runtime dependencies
- Fix build without python2
* Thu Feb 28 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.1
  Bugfixes:
  * ProjectMembership resource ``group`` attribute was returned as
    a dict instead of being converted to Resource object
- Update to version 2.2.0
  Improvements:
  * ``PerformanceWarning`` will be issued when Python-Redmine does
    some unnecessary work under the hood to fix the clients code
    problems
  Changes:
  * *Backwards Incompatible:* Removed vendored Requests package
    and make it an external dependency as Requests did the same with
    it's own dependencies
  * *Backwards Incompatible:* Removed Python 2.6 and 3.3 support as
    they're not supported by Requests anymore
  Bugfixes:
  * ``Redmine.upload()`` fails under certain circumstances when used
    with a file-like object and it contains unicode instead of bytes
  * - ``Redmine.session()`` doesn't restore previous engine if fails
- Update patch:
  * python-python-redmine-use-system-requests.patch
* Wed Apr 11 2018 mardnh@gmx.de
- Use %%license for license install
* Wed Apr 11 2018 mardnh@gmx.de
- Initial package, version 2.0.2
- Add patch:
  * python-python-redmine-use-system-requests.patch
